package com.ruoyi.mall.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mall.mapper.MallExpeditingGoodsMapper ;
import com.ruoyi.mall.domain.MallExpeditingGoods ;
import com.ruoyi.mall.service.IMallExpeditingGoodsService ;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-03
 */
@Service
public class MallExpeditingGoodsServiceImpl implements IMallExpeditingGoodsService 
{
    @Autowired
    private MallExpeditingGoodsMapper mallExpeditingGoodsMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public MallExpeditingGoods selectMallExpeditingGoodsById(Long id)
    {
        return mallExpeditingGoodsMapper.selectMallExpeditingGoodsById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param mallExpeditingGoods 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<MallExpeditingGoods> selectMallExpeditingGoodsList(MallExpeditingGoods mallExpeditingGoods)
    {
        return mallExpeditingGoodsMapper.selectMallExpeditingGoodsList(mallExpeditingGoods);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param mallExpeditingGoods 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertMallExpeditingGoods(MallExpeditingGoods mallExpeditingGoods)
    {
        return mallExpeditingGoodsMapper.insertMallExpeditingGoods(mallExpeditingGoods);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param mallExpeditingGoods 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateMallExpeditingGoods(MallExpeditingGoods mallExpeditingGoods)
    {
        return mallExpeditingGoodsMapper.updateMallExpeditingGoods(mallExpeditingGoods);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteMallExpeditingGoodsByIds(Long[] ids)
    {
        return mallExpeditingGoodsMapper.deleteMallExpeditingGoodsByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteMallExpeditingGoodsById(Long id)
    {
        return mallExpeditingGoodsMapper.deleteMallExpeditingGoodsById(id);
    }
}
